Candle class

Candle model wich holds a single candle data. It contains five required double variables that hold a single candle data: high, low, open, close and volume. It can be instantiated using its default constructor or fromJson named custructor.

Constructors

Candle({required DateTime date, required double high, required double low, required double open, required double close, required double volume})
Candle.fromJson(List json)

Properties

close → double
Price at the end of the period
final
date → DateTime
DateTime for the candle
final
hashCode → int
The hash code for this object.
no setterinherited
high → double
The highet price during this candle lifetime It if always more than low, open and close
final
isBull → bool
no setter
low → double
The lowest price during this candle lifetime It if always less than high, open and close
final
open → double
Price at the beginnig of the period
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
volume → double
Volume is the number of shares of a security traded during a given period of time.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited