TriangleAnnotation class
- Inheritance
-
- Object
- Annotation
- TriangleAnnotation
Constructors
- TriangleAnnotation({String? text, double radius = 5, Color color = Colors.green, TextStyle? textStyle, AnnotationAlignment annotationAlignment = AnnotationAlignment.Bottom})
Properties
- annotationAlignment → AnnotationAlignment
-
final
- color → Color
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- radius → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → String?
-
final
- textStyle → TextStyle?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
paint(
PaintingContext context, Offset candleTop, Offset candleBottom) → void -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited